@@ -3,8 +3,11 @@ import os
 
 from dateutil.tz import tzutc
 
+from brightsky.utils import load_dotenv
+
 
 CORS_ALLOWED_ORIGINS = []
+CORS_ALLOWED_HEADERS = []
 DATABASE_URL = 'postgres://localhost'
 ICON_CLOUDY_THRESHOLD = 80
 ICON_PARTLY_CLOUDY_THRESHOLD = 25
@@ -50,6 +53,7 @@ class Settings(dict):
         self.loaded = False
 
     def load(self):
+        load_dotenv()
         for k, v in globals().items():
             if k.isupper() and not k.startswith('_'):
                 self[k] = v
